==> download.php?file=Net2Plan-0.3.0.zip: com/net2plan/internal/Version.java <==
/*******************************************************************************
 * Copyright (c) 2013-2015 Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * Contributors:
 *     Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza - initial API and implementation
 ******************************************************************************/
package com.net2plan.internal;

/**
 * Class enclosing the current version of the kernel.
 *
 * @author Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza
 * @since 0.2.0
 */
public class Version
{
	private final static String version = "Net2Plan 0.3.0";
	private final static String fileFormatVersion = "3";
	
	/**
	 * Returns the current <code>.n2p</code> file format version.
	 *
	 * @return <code>String</code> representation of the <code>.n2p</code> file format version
	 * @since 0.3.0
	 */
	public static String getFileFormatVersion()
	{
		return fileFormatVersion;
	}

	/**
	 * Returns a <code>String</code> representation of the object.
	 *
	 * @return <code>String</code> representation of the object
	 * @since 0.2.3
	 */
	public static String getVersion()
	{
		return version;
	}

	/**
	 * Returns a <code>String</code> representation of the object.
	 *
	 * @return <code>String</code> representation of the object
	 * @since 0.2.0
	 */
	@Override
	public String toString()
	{
		return getVersion();
	}
}

==> download.php?file=Net2Plan-0.3.1.zip: com/net2plan/internal/Version.java <==
/*******************************************************************************
 * Copyright (c) 2013-2015 Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * Contributors:
 *     Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza - initial API and implementation
 ******************************************************************************/
package com.net2plan.internal;

/**
 * Class enclosing the current VERSION of the kernel.
 *
 * @author Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza
 * @since 0.2.0
 */
public class Version
{
	private final static String VERSION = "0.3.1";
	private final static String FILE_FORMAT_VERSION = "3";
	
	/**
	 * Returns the current {@code .n2p} file format VERSION.
	 *
	 * @return {@code String} representation of the {@code .n2p} file format VERSION
	 * @since 0.3.0
	 */
	public static String getFileFormatVersion()
	{
		return FILE_FORMAT_VERSION;
	}

	/**
	 * Returns a {@code String} representation of the object.
	 *
	 * @return {@code String} representation of the object
	 * @since 0.2.3
	 */
	public static String getVersion()
	{
		return VERSION;
	}

	/**
	 * Returns a {@code String} representation of the object.
	 *
	 * @return {@code String} representation of the object
	 * @since 0.2.0
	 */
	@Override
	public String toString()
	{
		return getVersion();
	}
}
